@@ -24,96 +24,43 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-iot-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.iotlambda`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS IoT MQTT topic rule and an AWS Lambda function pattern.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
+```javascript
+const { IotToLambdaProps, IotToLambda } from '@aws-solutions-constructs/aws-iot-lambda';
 
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { IotToLambdaProps, IotToLambda } from '@aws-solutions-constructs/aws-iot-lambda';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-const constructProps: IotToLambdaProps = {
-  lambdaFunctionProps: {
-    code: lambda.Code.fromAsset(`lambda`),
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler'
-  },
-  iotTopicRuleProps: {
-    topicRulePayload: {
-      ruleDisabled: false,
-      description: "Processing of DTC messages from the AWS Connected Vehicle Solution.",
-      sql: "SELECT * FROM 'connectedcar/dtc/#'",
-      actions: []
+const props: IotToLambdaProps = {
+    lambdaFunctionProps: {
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+        runtime: lambda.Runtime.NODEJS_10_X,
+        handler: 'index.handler'
+    },
+    iotTopicRuleProps: {
+        topicRulePayload: {
+            ruleDisabled: false,
+            description: "Processing of DTC messages from the AWS Connected Vehicle Solution.",
+            sql: "SELECT * FROM 'connectedcar/dtc/#'",
+            actions: []
+        }
     }
-  }
 };
 
-new IotToLambda(this, 'test-iot-lambda-integration', constructProps);
+new IotToLambda(this, 'test-iot-lambda-integration', props);
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_iot_lambda import IotToLambdaProps, IotToLambda
-from aws_cdk import (
-    aws_iot as iot,
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-IotToLambda(self, 'test_iot_lambda',
-            lambda_function_props=_lambda.FunctionProps(
-                code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.PYTHON_3_9,
-                handler='index.handler'
-            ),
-            iot_topic_rule_props=iot.CfnTopicRuleProps(
-                topic_rule_payload=iot.CfnTopicRule.TopicRulePayloadProperty(
-                    rule_disabled=False,
-                    description="Sends data to kinesis data stream",
-                    sql="SELECT * FROM 'solutions/construct'",
-                    actions=[]
-                )
-            ))
+```text
+new IotToLambda(scope: Construct, id: string, props: IotToLambdaProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-import java.util.List;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awscdk.services.iot.*;
-import software.amazon.awscdk.services.iot.CfnTopicRule.TopicRulePayloadProperty;
-import software.amazon.awsconstructs.services.iotlambda.*;
-
-new IotToLambda(this, "test-iot-lambda-integration", new IotToLambdaProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .iotTopicRuleProps(new CfnTopicRuleProps.Builder()
-                .topicRulePayload(new TopicRulePayloadProperty.Builder()
-                        .ruleDisabled(false)
-                        .description("Processing of DTC messages from the AWS Connected Vehicle Solution.")
-                        .sql("SELECT * FROM 'connectedcar/dtc/#'")
-                        .actions(List.of())
-                        .build())
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`IotToLambdaProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -154,7 +101,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -166,28 +113,26 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_iot
 import aws_cdk.aws_lambda
-import aws_cdk.core
+import constructs
 
 
 class IotToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambda",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -200,10 +145,6 @@ class IotToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the IotToLambda class.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(IotToLambda.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToLambdaProps(
             iot_topic_rule_props=iot_topic_rule_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -212,12 +153,12 @@ class IotToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
@@ -236,9 +177,9 @@ class IotToLambdaProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
@@ -251,11 +192,6 @@ class IotToLambdaProps:
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        if __debug__:
-            type_hints = typing.get_type_hints(IotToLambdaProps.__init__)
-            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
